@@ -1,4 +1,5 @@
 use crate::barbfile::BarbFile;
+use crate::output::BarbOutput;
 
 use std::collections::HashMap;
 use ureq;
@@ -57,32 +58,24 @@ impl Executor {
         Executor { context }
     }
 
-    fn make_req(&self, bfile: &BarbFile, print_req: bool, print_headers: bool) -> ureq::Request {
-        if print_req {
-            println!(
-                "{} {}",
-                bfile.method_as_string().as_str(),
-                self.context.substitute(&bfile.url()).as_str()
-            );
-        }
+    fn make_req(&self, bfile: &BarbFile, output: &BarbOutput) -> ureq::Request {
+        output.req(
+            bfile.method_as_string(),
+            self.context.substitute(&bfile.url()),
+        );
         let mut req = ureq::request(
             bfile.method_as_string().as_str(),
             self.context.substitute(&bfile.url()).as_str(),
         );
 
         for header in bfile.headers() {
-            req = req.set(
-                header.name(),
-                self.context.substitute(header.value()).as_str(),
-            );
-            if print_headers {
-                println!(
-                    "{} {}",
-                    header.name(),
-                    self.context.substitute(header.value())
-                );
-            }
+            let hdr_val = self.context.substitute(header.value());
+            req = req.set(header.name(), hdr_val.as_str());
+            output.req_hdr(header.name().to_string(), hdr_val);
         }
+
+        output.end_req();
+
         req
     }
 
@@ -105,10 +98,9 @@ impl Executor {
     pub fn execute(
         &mut self,
         bfile: &BarbFile,
-        print_req: bool,
-        print_headers: bool,
+        output: &BarbOutput,
     ) -> Result<ureq::Response, String> {
-        self.run(bfile, self.make_req(&bfile, print_req, print_headers))
+        self.run(bfile, self.make_req(&bfile, output))
     }
 }
 
@@ -145,7 +137,8 @@ mod tests {
     fn test_make_req_simple_get() {
         let executor = Executor::new(Context::empty());
         let bfile = BarbFile::from_str("#GET^http://foo.bar\n\n").unwrap();
-        let req = executor.make_req(&bfile, false, false);
+        let output = BarbOutput::new(false, false, false, false, false, false);
+        let req = executor.make_req(&bfile, &output);
 
         assert_eq!(req.url(), "http://foo.bar");
         assert_eq!(req.method(), "GET");
@@ -155,7 +148,8 @@ mod tests {
     fn test_make_req_simple_headers() {
         let executor = Executor::new(Context::empty());
         let bfile = BarbFile::from_str("#GET^http://foo.bar\n#Foo: Bar\n#Bar: Baz\n\n").unwrap();
-        let req = executor.make_req(&bfile, false, false);
+        let output = BarbOutput::new(false, false, false, false, false, false);
+        let req = executor.make_req(&bfile, &output);
 
         assert_eq!(
             req.header_names(),
