@@ -4,6 +4,14 @@ from bottle import get, post, run, HTTPError
 def get_root():
     return {"status": "OK"}
 
+@get("/long")
+def get_long():
+    return {"data": [
+        {"name": "apple", "calories": 5},
+        {"name": "orange", "calories": 120},
+        {"name": "pear", "calories": 45},
+    ]}
+
 @post("/")
 def post_root():
     return {"status": "SUCCESS"}
